@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
 from pre_commit.languages import helpers
-from pre_commit.xargs import xargs
 
 
 ENVIRONMENT_DIR = None
@@ -10,7 +9,7 @@ healthy = helpers.basic_healthy
 install_environment = helpers.no_install
 
 
-def run_hook(prefix, hook, file_args):
+def run_hook(hook, file_args):
     cmd = helpers.to_cmd(hook)
-    cmd = (prefix.path(cmd[0]),) + cmd[1:]
-    return xargs(cmd, file_args)
+    cmd = (hook.prefix.path(cmd[0]),) + cmd[1:]
+    return helpers.run_xargs(hook, cmd, file_args)
